@@ -2,9 +2,9 @@
 # NUCLEOTIDE: Q <- list(pi = c(0.25, 0.25, 0.25, 0.25), kappa = 0.5)
 # SNP: Q <- list(pi = c(0.5, 0.5), kappa = 0.5)
 
-phyclust.Pt <- function(Q, Tt, substitution.model = .substitution$model[1]){
-  sub.model <- which(substitution.model[1] == as.character(.substitution$model))
-  code.type <- which(as.character(.substitution$code.type[sub.model]) ==
+phyclust.Pt <- function(Q, Tt, substitution.model = .substitution.model$model[1]){
+  sub.model <- which(substitution.model[1] == as.character(.substitution.model$model))
+  code.type <- which(as.character(.substitution.model$code.type[sub.model]) ==
                                   .code.type)
   ret <- .Call("R_phyclust_logPt",
                as.double(Q$pi),
@@ -13,7 +13,7 @@ phyclust.Pt <- function(Q, Tt, substitution.model = .substitution$model[1]){
                as.integer(code.type - 1),
                as.integer(sub.model - 1),
                PACKAGE = "phyclust")
-  if(as.character(.substitution$code.type[sub.model]) == "NUCLEOTIDE"){
+  if(as.character(.substitution.model$code.type[sub.model]) == "NUCLEOTIDE"){
     ret$Pt <- matrix(ret$Pt, nrow = 4, ncol = 4, byrow = TRUE)
     ret$log.Pt <- matrix(ret$log.Pt, nrow = 4, ncol = 4, byrow = TRUE)
     ret$H <- matrix(ret$H, nrow = 1, ncol = 4, byrow = TRUE)
@@ -23,7 +23,7 @@ phyclust.Pt <- function(Q, Tt, substitution.model = .substitution$model[1]){
     ret$H <- matrix(ret$H, nrow = 1, ncol = 2, byrow = TRUE)
   }
   attr(ret, "class") <- "Pt"
-  attr(ret, "code.type") <- as.character(.substitution$code.type[sub.model])
+  attr(ret, "code.type") <- as.character(.substitution.model$code.type[sub.model])
   ret
 }
 
